@@ -1,9 +1,9 @@
 from typing import Any
 from uuid import UUID
 
+from asgiref.sync import sync_to_async
+
 from fastadmin.models.base import InlineModelAdmin, ModelAdmin
-from fastadmin.models.decorators import sync_to_async
-from fastadmin.models.helpers import get_admin_model
 from fastadmin.models.schemas import ModelFieldWidgetSchema, WidgetType
 from fastadmin.settings import settings
 
@@ -133,11 +133,7 @@ class DjangoORMMixin:
                 rel_model_cls = orm_model_field.related_model
                 rel_model = rel_model_cls.__name__
                 rel_model_id_field = self.get_model_pk_name(rel_model_cls)
-
-                rel_model_label_fields = (rel_model_id_field,)
-                parent_admin_model = get_admin_model(rel_model_cls)
-                if parent_admin_model and parent_admin_model.label_fields:
-                    rel_model_label_fields = parent_admin_model.label_fields
+                rel_model_label_fields = ("__str__", rel_model_id_field)
 
                 match field_type:
                     case "OneToOneField":
